@@ -46,19 +46,27 @@ YACReader::WhatsNewDialog::WhatsNewDialog(QWidget *parent)
                                 "color:#858585;");
 
     auto text = new QLabel();
-    text->setText("Update to add support for remote search through the server:<br/>"
+    text->setText("New metadata support and better search engine:<br/>"
+                  "<br/>"
+                  "<span style=\"font-weight:600\">YACReader</span><br/>"
+                  "   &#8226; Add shortcuts for moving by one the double page mode to the left/right, by default CTRL + SHIFT + LEFT, and,  CTRL + SHIFT + RIGHT. Remember that you can change any shortcut in the shortcuts dialog. You can also achieve this functionality using the 'Go to page flow' and chossing the page you want to be on the left/right (depending on the reading mode comic/manga).<br/>"
                   "<br/>"
                   "<span style=\"font-weight:600\">YACReaderLibrary</span><br/>"
-                  "   &#8226; Fix scroll in grid views when using Qt6 builds.<br/>"
-                  "   &#8226; Fix deleting metadata from comics, it also deleted the number of pages info.<br/>"
-                  "   &#8226; Do not accept empty values for the server port in the server settings dialog.<br/>"
-                  "   &#8226; New way of generating QR codes.<br/>"
-                  "<br/>"
-                  "<span style=\"font-weight:600\">YACReaderLibraryServer</span><br/>"
-                  "   &#8226; Print scannable QR code at server start.<br/>"
-                  "<br/>"
-                  "<span style=\"font-weight:600\">Server</span><br/>"
-                  "   &#8226; New search API that exposes the search engine. This will be used by the upcoming updates for the iOS & Android apps.<br/>"
+                  "   &#8226; Avoid showing stale information in the server config dialog by updating the connection information when the dialog is opened.<br/>"
+                  "   &#8226; Add new metadata support, it improves compatibility with ComicInfo.xml.<br/>"
+                  "   &#8226; Add support for showing a 'recently added/updated' indicator.<br/>"
+                  "   &#8226; Improved comic metadata dialog.<br/>"
+                  "   &#8226; Add textual tags support that can be queried through the search engine.<br/>"
+                  "   &#8226; Make '=' in the search engine work as ':' does.<br/>"
+                  "   &#8226; Add new operators to the search engine: exact match ==, <, >, <=, >=.<br/>"
+                  "   &#8226; Support filtering by since/before dates in the search engine. e.g. `added > 7` means recent content added since 7 days ago, and `added < 30` means content added before the last 30 days.<br/>"
+                  "   &#8226; Show the full library path in the dialog shown to warn about missing libraries.<br/>"
+                  "   &#8226; Fix scroll bar in the info comics view in Qt6 builds.<br/>"
+                  "   &#8226; New `Recent` smart list, it will show recent comics added.<br/>"
+                  "   &#8226; Try to detect changed files with the same name on libraries updates, there is also a new setting to decide if the modified date of a file should be used as an indicator to know if the file has been changed since it was added (disabled by default, it shouldn't be neccessary in most cases).<br/>"
+                  "   &#8226; Fix alphanumeric navigation in the folders tree view. Shortcuts were interfering the default behaviour, now some shortcuts will be ignored if the folders tree has the focus.<br/>"
+                  "   &#8226; Fix sorting in the Comic Vine series selection dialog.<br/>"
+                  "   &#8226; Fix getting only distinct rows when querying folders through the search engine. The fix is noticeable only in the iOS and Android clients.<br/>"
                   "<br/>"
                   "I hope you enjoy the new update. Please, if you like YACReader consider to become a patron in <a href=\"https://www.patreon.com/yacreader\" style=\"color:#E8B800;\">Patreon</a> "
                   "or donate some money using <a href=\"https://www.paypal.com/donate?business=5TAMNQCDDMVP8&item_name=Support+YACReader\" style=\"color:#E8B800;\">Pay-Pal</a> and help keeping the project alive. "
